Skip to content
KitploitKITPLOIT
FerramentasExploitsBlog
Log in
Enviar
FerramentasExploitsBlog
Enviar

Ferramentas de Hacking, PenTest e Cibersegurança para o seu Arsenal de Segurança!

Kitploit é um diretório de ferramentas de hacking, cibersegurança e pentesting. Descubra as últimas atualizações de projetos para encontrar vulnerabilidades, analisar sistemas, automatizar testes e fortalecer sua segurança.

··Feeds·Contato·Privacidade·© 2026 Kitploit

Diretório de Ferramentas

Categorias

Ver todas as categorias
Loading categories
MacMaster — Gerenciamento e Monitoramento Avançados de Interfaces de Rede | Kitploit
Ferramentas/GitHubGitHub/halildeniz/macmaster
Sniffing e Análise de PacotesAuditoria de Wi-FiColeta de InformaçõesSegurança de RedeTestes de Penetração
GitHubhalildeniz/macmaster

MacMaster

Gerenciamento e Monitoramento Avançados de Interfaces de Rede

Ver Repositório
341016há 2 anosRevisado pelo Kitploit
Site

Mais Populares

Ver todos →

Descubra as ferramentas mais usadas pela nossa comunidade.

Explore todas as ferramentas

Navegue pela nossa coleção de ferramentas

Ver todas as ferramentas →
Compartilhar

MacMaster: Gerenciamento e Monitoramento Avançado de Interface de Rede

O MacMaster é uma ferramenta de linha de comando abrangente, criada tanto para profissionais de rede quanto para entusiastas. Ele se destaca como um utilitário poderoso para manipular os endereços MAC de interfaces de rede em vários sistemas. Projetado com simplicidade e funcionalidade em mente, o MacMaster é excelente em fornecer soluções para melhorar o anonimato na rede, realizar testes de segurança e executar uma ampla gama de tarefas de diagnóstico e monitoramento de rede. Seja para anonimizar sua presença na rede, solucionar problemas de conectividade ou se envolver em análises avançadas de rede, o MacMaster fornece as ferramentas necessárias para realizar essas tarefas de forma eficiente.

Recursos

  • Endereço MAC personalizado: Defina um endereço MAC específico para sua interface de rede.
  • Endereço MAC aleatório: Gere e defina um endereço MAC aleatório.
  • Redefinir para o original: Redefina o endereço MAC para seu valor de hardware original.
  • OUI personalizado: Defina um Identificador Único de Organização (OUI) personalizado para o endereço MAC.
  • Informações da versão: Verifique facilmente a versão do MacMaster que você está usando.
  • Listagem de interfaces de rede: Liste facilmente todas as interfaces de rede disponíveis.
  • Alternância de modo de interface: Alterne interfaces de rede sem fio entre os modos 'gerenciado' e 'monitor'.
  • Redefinição de serviços de rede: Redefina rapidamente os serviços de rede para aplicar alterações ou solucionar problemas.
  • Monitoramento de tráfego de rede: Monitore o tráfego MAC em tempo real para análise e testes de segurança.

Instalação

O MacMaster requer Python 3.6 ou posterior.

  1. Clone o repositório:
    $ git clone https://github.com/HalilDeniz/MacMaster.git
    
  2. Navegue até o diretório clonado:
    cd MacMaster
    
  3. Instale o pacote:
    $ python setup.py install
    

Uso

$ macmaster.py --help
usage: macmaster.py [-h] [--interface INTERFACE] [--list-interfaces] [--version]
                    [--random | --newmac NEWMAC | --customoui CUSTOMOUI | --reset]
                    [--mode {managed,monitor,master,auto,repeater}] [--get-ssid] [--check-security]
                    [--analyze-signal] [--restart-network] [--monitor-mac-traffic] [--analyze-packets]

MacMaster: Advanced Network Interface Management and Monitoring

options:
  -h, --help            show this help message and exit
  --interface INTERFACE, -i INTERFACE
                        Network interface to change MAC address
  --list-interfaces, -li
                        List all network interfaces
  --version, -V         Show the version of the program
  --random, -r          Set a random MAC address
  --newmac NEWMAC, -nm NEWMAC
                        Set a specific MAC address
  --customoui CUSTOMOUI, -co CUSTOMOUI
                        Set a custom OUI for the MAC address
  --reset, -rs          Reset MAC address to the original value
  --mode {managed,monitor,master,auto,repeater}
                        Change interface mode to managed or monitor
  --get-ssid            Get the SSID of the wireless interface
  --check-security      Check the security protocol of the wireless interface
  --analyze-signal      Analyze the signal strength and quality of the wireless interface
  --restart-network, -rn
                        Restart network services
  --monitor-mac-traffic, -mmt
                        Live Monitor Mac traffic
  --analyze-packets, -ap
                        Analyze network packets on the interface

Argumentos

  • --interface, -i: Especifique a interface de rede a ser usada para operações de endereço MAC.
  • --random, -r: Gere e defina um endereço MAC aleatório na interface especificada.
  • --newmac, -nm: Defina um endereço MAC específico na interface especificada.
  • --customoui, -co: Defina um Identificador Único de Organização (OUI) personalizado para o endereço MAC na interface especificada.
  • --reset, -rs: Redefina o endereço MAC da interface especificada para seu valor de hardware original.
  • --version, -V: Mostre a versão atual do MacMaster.
  • --list-interfaces, -li: Liste todas as interfaces de rede disponíveis no sistema.
  • --mode, -m: Altere o modo de uma interface de rede sem fio (opções incluem 'managed', 'monitor', 'master', 'auto', 'repeater').
  • --restart-network, -rn: Reinicie os serviços de rede para aplicar alterações ou solucionar problemas de rede.
  • --monitor-mac-traffic, -mmt: Monitore e exiba o tráfego MAC em tempo real na interface especificada.
  • --get-ssid, -gs: Exiba o SSID da rede Wi-Fi conectada.
  • --analyze-signal, -as: Analise a intensidade e qualidade do sinal da interface sem fio.
  • --check-security, -cs: Verifique o protocolo de segurança da interface sem fio.
  • --analyze-packets, -ap: Analise pacotes de rede na interface.

Exemplos

  1. Definir um endereço MAC específico:
    macmaster -i eth0 -nm 00:11:22:33:44:55
    
  2. Definir um endereço MAC aleatório:
    macmaster -i eth0 -r
    
  3. Redefinir o endereço MAC para seu valor original:
    macmaster -i eth0 -rs
    
  4. Listar todas as interfaces de rede:
    macmaster -li
    
  5. Alterar o modo da interface:
    macmaster -i eth0 -m monitor
    
  6. Reiniciar serviços de rede:
    macmaster -rn
    
  7. Monitorar tráfego MAC em tempo real:
    macmaster -i eth0 -mmt
    

Nota

Você deve executar este script como root ou usar sudo para que funcione corretamente. Isso ocorre porque alterar um endereço MAC requer privilégios de root.

Contribuindo

Contribuições são bem-vindas! Para contribuir com o MacMaster, siga estas etapas:

  1. Faça um fork do repositório.
  2. Crie um novo branch para sua funcionalidade ou correção de bug.
  3. Faça suas alterações e faça commit delas.
  4. Envie suas alterações para o repositório forkado.
  5. Abra um pull request no repositório principal.

Contato

Para quaisquer dúvidas ou informações adicionais, você pode entrar em contato comigo através dos seguintes canais:

Contato

  • Linktr :Halil Deniz
  • LinkedIn : Halil İbrahim Deniz
  • TryHackMe : halilovic
  • Instagram : deniz.halil333
  • YouTube : HalilDeniz
  • Email: [email protected]

Licença

O MacMaster é distribuído sob a licença MIT. Consulte LICENSE para mais informações.

Baixar ferramenta